'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});
var utilsCommons = require('@highlight-ui/utils-commons');
var React = require('react');
var typography = require('@highlight-ui/typography');
var classnames = require('classnames');
var compose = require('lodash/fp/compose');
var curryN = require('lodash/fp/curryN');
var icon = require('@highlight-ui/icon');
function _interopDefaultLegacy(e) {
  return e && typeof e === 'object' && 'default' in e ? e : {
    'default': e
  };
}
var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
var classnames__default = /*#__PURE__*/_interopDefaultLegacy(classnames);
var compose__default = /*#__PURE__*/_interopDefaultLegacy(compose);
var curryN__default = /*#__PURE__*/_interopDefaultLegacy(curryN);

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function () {
  __assign = Object.assign || function __assign(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];
      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }
    return t;
  };
  return __assign.apply(this, arguments);
};
function __spreadArray(to, from, pack) {
  if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
    if (ar || !(i in from)) {
      if (!ar) ar = Array.prototype.slice.call(from, 0, i);
      ar[i] = from[i];
    }
  }
  return to.concat(ar || Array.prototype.slice.call(from));
}
var Nav = function (_a) {
  var buttonClassName = _a.buttonClassName,
    className = _a.className,
    page = _a.page,
    icon$1 = _a.icon,
    onClick = _a.onClick;
  return React__default["default"].createElement("li", __assign({
    className: className
  }, utilsCommons.parseMetadata({
    testId: 'pagination-nav'
  })), React__default["default"].createElement("button", {
    type: "button",
    "data-page": page,
    onClick: onClick,
    className: buttonClassName,
    tabIndex: 0
  }, React__default["default"].createElement(icon.Icon, {
    name: icon$1,
    color: "icon-default",
    size: 12
  })));
};
function calcCenterPagePosition(maxItems) {
  return Math.ceil(maxItems / 2);
}
function calcMaxPage(limit, total) {
  return Math.ceil(total / limit);
}
function calcOffset(limit, page) {
  return page * limit - limit;
}
function calcPage(limit, offset) {
  return Math.ceil((offset + limit) / limit);
}
function getPageFromEvent(e) {
  var _a;
  return (_a = e.currentTarget.dataset.page) !== null && _a !== void 0 ? _a : '';
}
function getPrevNumberList(acc, num, limit) {
  return num <= 1 || limit < 1 ? acc : getPrevNumberList(__spreadArray([num - 1], acc, true), num - 1, limit - 1);
}
function incrementList(acc, maxLength, limit, page) {
  return acc.length >= maxLength || page > limit ? acc : incrementList(__spreadArray(__spreadArray([], acc, true), [page], false), maxLength, limit, page + 1);
}
var styles = {
  "pageButton": "Pagination-module__b6UNFDXg__v3-2-21",
  "pagination": "Pagination-module__Kih79lZS__v3-2-21",
  "page": "Pagination-module__GmQEljiw__v3-2-21",
  "activePage": "Pagination-module__UZXLRGlr__v3-2-21"
};
var Pagination = React__default["default"].forwardRef(function (_a, ref) {
  var className = _a.className,
    metadata = _a.metadata,
    _b = _a.firstPageIconName,
    first = _b === void 0 ? 'angle-double-left' : _b,
    _c = _a.prevPageIconName,
    prev = _c === void 0 ? 'angle-left' : _c,
    _d = _a.nextPageIconName,
    next = _d === void 0 ? 'angle-right' : _d,
    _e = _a.lastPageIconName,
    last = _e === void 0 ? 'angle-double-right' : _e,
    limit = _a.limit,
    _f = _a.maxItems,
    maxItems = _f === void 0 ? 0 : _f,
    offset = _a.offset,
    onChange = _a.onChange,
    total = _a.total;
  var maxPage = calcMaxPage(limit, total);
  var page = calcPage(limit, offset);
  var centerIndex = calcCenterPagePosition(maxItems);
  var previousPages = getPrevNumberList([], page, centerIndex - 1);
  var displayList = incrementList(previousPages, maxItems, maxPage, page);
  var getOffsetOf = curryN__default["default"](2, calcOffset)(limit);
  var onPaginate = compose__default["default"]([onChange, getOffsetOf, Number, getPageFromEvent]);
  return React__default["default"].createElement("ul", __assign({
    className: classnames__default["default"](styles.pagination, className),
    ref: ref
  }, utilsCommons.parseMetadata(metadata)), page > 1 && React__default["default"].createElement(React__default["default"].Fragment, null, React__default["default"].createElement(Nav, {
    page: 1,
    icon: first,
    onClick: onPaginate,
    buttonClassName: styles.pageButton
  }), React__default["default"].createElement(Nav, {
    page: page - 1,
    icon: prev,
    onClick: onPaginate,
    buttonClassName: styles.pageButton
  })), displayList.map(function (innerPage) {
    var _a;
    return React__default["default"].createElement("li", __assign({}, utilsCommons.parseMetadata({
      testId: "pagination-page-container-" + innerPage
    }), {
      key: innerPage,
      className: classnames__default["default"](styles.page, (_a = {}, _a[styles.activePage] = innerPage === page, _a))
    }), React__default["default"].createElement(typography.Typography, __assign({}, utilsCommons.parseMetadata({
      testId: "pagination-page-" + innerPage
    }), {
      component: "button",
      token: "body-base",
      "data-page": innerPage,
      className: styles.pageButton,
      onClick: onPaginate
    }), innerPage));
  }), page < maxPage && React__default["default"].createElement(React__default["default"].Fragment, null, React__default["default"].createElement(Nav, {
    page: page + 1,
    icon: next,
    onClick: onPaginate,
    buttonClassName: styles.pageButton
  }), React__default["default"].createElement(Nav, {
    page: maxPage,
    icon: last,
    onClick: onPaginate,
    buttonClassName: styles.pageButton
  })));
});
exports.Pagination = Pagination;
//# sourceMappingURL=index.js.map
